--[[
	Kills Confirmed Gamemode
	Based on one of Call of Duty gamemode
	For CS2D
	By Avobolt (USGN #88318)
]]--
kc = {
	Setup = {
		TileLimit = 3,							--// How many signs possible in one place
		OwnTeam = 100,							--// Reward for collecting sign of dead teammate ($)
		OtherTeam = 300,						--// Reward for collecting sign of dead enemy ($)
		OwnSign = 150,							--// Reward for collecting your sign ($)
		UpdateHook = "movetile",				--// Hookname; "movetile"/"use"
		KillConfirmedSound = "wpn_select.wav",	--// Path of the sound you want to be played every confirmation		
		KillConfirmedSoundEnabled = false,		--// Confirmation sound enabled?
		SignImage = "gfx/gui_load.bmp",			--// Path of sign image
		AnnoyingMessagesEnabled = true			--// Show all messages?
	},
	Map = {},
	NewSign = function(x, y, team, player)
		kc.Map[x.."x"..y] = kc.Map[x.."x"..y] or {}
		if #kc.Map[x.."x"..y] < kc.Setup.TileLimit then
			local img = image(kc.Setup.SignImage, x * 32 + math.random(8, 24), y * 32 + math.random(8, 24), 1)
			tween_rotateconstantly(img, 15)
			imageblend(img, 1)
			imagescale(img, 1.2, 1.2)
			imagecolor(img, 0, 255, 0)
			table.insert(kc.Map[x.."x"..y], {Image = img, Team = team, Player = (player or 0)})
			return true
		end
		return false
	end,
	RemoveSign = function(x, y, id)
		if not id then
			for i = 1, #kc.Map[x.."x"..y] do
				freeimage(kc.Map[x.."x"..y][i].Image)
			end
			kc.Map[x.."x"..y] = nil
		else
			freeimage(kc.Map[x.."x"..y][id].Image)
			kc.Map[x.."x"..y][id] = nil
		end
	end,
	HookHit = function(id, src, wpn, dmg)
		if (player(id, "health") - dmg) <= 0 and player(id, "team") ~= player(src, "team") then
			if player(id, "tilex") ~= player(src, "tilex") or player(id, "tiley") ~= player(src, "tiley") then
				kc.NewSign(player(id, "tilex"), player(id, "tiley"), player(id, "team"), id)
				parse("setscore "..src.." "..(player(src, "score") - 1))
				parse("setmoney "..src.." "..(player(src, "money") - 300))
			else
				if kc.Setup.AnnoyingMessagesEnabled then
					msg("Kill confirmed!@C")
					msg2(id, "> You picked up your kill-sign!")
				end
			end
		end
	end,
	HookStartRound = function()
		kc.Map = {}
	end,
	HookLeave = function(id)
		for k, v in pairs(kc.Map) do
			for i = 1, #v do
				if v[i].Player == id then
					kc.Map[k][i] = 0
				end
			end
		end
	end,
	Update = function(id)
		kc.Check(id, player(id, "tilex"), player(id, "tiley"))
	end,
	Check = function(id, x, y)
		kc.Map[x.."x"..y] = kc.Map[x.."x"..y] or {}
		if #kc.Map[x.."x"..y] > 0 then
			if kc.Setup.KillConfirmedSoundEnabled then
				parse('sv_sound2 '..id..' "'..kc.Setup.KillConfirmedSound..'"')
			end
			if kc.Setup.AnnoyingMessagesEnabled then
				msg("Kill confirmed!@C")
			end
			for i = 1, #kc.Map[x.."x"..y] do
				if kc.Map[x.."x"..y][i].Team ~= player(id, "team") then
					parse("setmoney "..id.." "..(player(id, "money") + kc.Setup.OtherTeam))
					if kc.Setup.AnnoyingMessagesEnabled then
						msg2(id, "> You picked up enemy's kill-sign!")
					end
				else
					if kc.Map[x.."x"..y][i].Player ~= id then
						parse("setmoney "..id.." "..(player(id, "money") + kc.Setup.OwnTeam))
						if kc.Setup.AnnoyingMessagesEnabled then
							msg2(id, "> You picked up your teammate's kill-sign!")
						end
					else
						parse("setmoney "..id.." "..(player(id, "money") + kc.Setup.OwnSign))
						if kc.Setup.AnnoyingMessagesEnabled then
							msg2(id, "> You picked up your kill-sign!")
						end
					end
				end
				parse("setscore "..id.." "..(player(id, "score") + 1))				
			end
			kc.RemoveSign(x, y)
		end
	end
}
addhook("hit", "kc.HookHit")
addhook("startround", "kc.HookStartRound")
addhook("leave", "kc.HookLeave")
addhook(kc.Setup.UpdateHook, "kc.Update")

parse("sv_friendlyfire 0")					--// Friendly fire disabled
parse("sv_gamemode 2")						--// Team deathmatch gamemode
parse("mp_hud 63")							--// Hide kill messages